import type { ACK, IDENTITY_PROVIDER, NACK } from '../dto';
import type { Ack, IdentityProvider, Nack, NackErrorWarning } from '../entity';
/**
 * @public
 */
export declare const fromDTOStringArray: (arr: string[]) => string[];
/**
 * getNormalisedText
 * @param arr - A NackErrorWarning array.
 * @returns A combined text string.
 * @internal
 */
export declare const getNormalisedText: (arr: NackErrorWarning[]) => string;
/**
 * hasDTOErrorWarningCode
 * @remarks
 * Checks both the `CODE` and `STATUS_CODE` values for a match.
 * @param dto - NACK.
 * @param code - The error or warning code.
 * @public
 */
export declare const hasDTOErrorWarningCode: (dto: NACK, code: string) => boolean;
/**
 * fromDTOAck
 * @param dto - ACK.
 * @public
 */
export declare const fromDTOAck: (dto: ACK) => Ack;
/**
 * fromDTONack
 * @param dto - NACK.
 * @public
 */
export declare const fromDTONack: (dto: NACK) => Nack;
/**
 * fromIDPDTO
 * @param dto - IDENTITY_PROVIDER.
 * @public
 */
export declare const fromIDPDTO: (dto: IDENTITY_PROVIDER) => IdentityProvider;
/**
 * isNackDTO.
 * @param dto - Potential NACK.
 * @public
 */
export declare function isNackDTO(dto: unknown): dto is NACK;
/**
 * isNackEntity.
 * @param entity - Potential Nack.
 * @public
 */
export declare function isNackEntity(entity: unknown): entity is Nack;
/**
 * createHTTPHeadersFromDTO.
 * @param dto - DTO being sent to the server.
 * @param contentType - Optional content-type, defaults to `application/json; charset=UTF-8`.
 * @public
 */
export declare function createHTTPHeadersFromDTO(dto: {
    SOURCE_REF?: string;
    USER_NAME?: string;
}, contentType?: string): HeadersInit;
//# sourceMappingURL=utils.d.ts.map