import { CustomEventMap } from '@genesislcap/foundation-events';
import { AbstractStore, Store } from '@genesislcap/foundation-store';
import { AuthConfig } from '../config/config';
import { CredentialManager } from '../credential';
import type { IdentityProvider } from '../entity';
import { IDPService } from '../services';
/**
 * @public
 */
export type AuthFormEntryEventMap = {
    'auth-autofill-form': void;
    'auth-organisation-changed': string;
    'auth-username-changed': string;
    'auth-email-changed': string;
    'auth-password-changed': string;
    'auth-password2-changed': string;
    'auth-showPassword-changed': boolean;
    'auth-selectedIdp-changed': string;
    'auth-ssoToggled-changed': boolean;
};
declare global {
    interface HTMLElementEventMap extends CustomEventMap<AuthFormEntryEventMap> {
    }
}
type InternalEventMap = {
    'auth-fetch-idps': void;
    'auth-fetch-idps-success': IdentityProvider[];
    'auth-fetch-idps-error': Error;
};
/**
 * AuthFormEntryStore interface.
 * @public
 */
export interface AuthFormEntryStore extends Store {
    readonly organisation: string;
    readonly username: string;
    readonly orgUsername: string;
    readonly email: string;
    readonly password: string;
    /**
     * @remarks
     * New, confirm etc.
     */
    readonly password2: string;
    readonly showPassword: boolean;
    readonly hasPasswordExpired: boolean;
    readonly passwordResetToken: string;
    readonly mfaCode: string;
    readonly idps: IdentityProvider[];
    readonly selectedIdp: IdentityProvider;
    readonly ssoLoginUrl: string;
    readonly ssoToggled: boolean;
    readonly termsAgreed: boolean;
    readonly autofilling: boolean;
    onOrganisationChanged(event: CustomEvent<string>): void;
    onUsernameChanged(event: CustomEvent<string>): void;
    onEmailChanged(event: CustomEvent<string>): void;
    onPasswordChanged(event: CustomEvent<string>): void;
    onPassword2Changed(event: CustomEvent<string>): void;
    onShowPasswordChanged(event: CustomEvent<boolean>): void;
    onSelectedIdpChanged(event: CustomEvent<string>): void;
    onSSOToggleChanged(event: CustomEvent<boolean>): void;
    onAutofillForm(event: CustomEvent<void>): void;
}
/**
 * Default AuthFormEntryStore.
 * @public
 */
export declare class DefaultAuthFormEntryStore extends AbstractStore<AuthFormEntryStore, AuthFormEntryEventMap, InternalEventMap> implements AuthFormEntryStore {
    protected config: AuthConfig;
    protected credentialManager: CredentialManager;
    readonly idpService: IDPService;
    /** {@inheritDoc AuthFormEntryStore.organisation} */
    organisation: string;
    /** {@inheritDoc AuthFormEntryStore.username} */
    username: string;
    /** {@inheritDoc AuthFormEntryStore.email} */
    email: string;
    /** {@inheritDoc AuthFormEntryStore.password} */
    password: string;
    /** {@inheritDoc AuthFormEntryStore.password2} */
    password2: string;
    /** {@inheritDoc AuthFormEntryStore.showPassword} */
    showPassword: boolean;
    /** {@inheritDoc AuthFormEntryStore.hasPasswordExpired} */
    hasPasswordExpired: boolean;
    /** {@inheritDoc AuthFormEntryStore.passwordResetToken} */
    passwordResetToken: string;
    /** {@inheritDoc AuthFormEntryStore.mfaCode} */
    mfaCode: string;
    /** {@inheritDoc AuthFormEntryStore.idps} */
    idps: IdentityProvider[];
    /** {@inheritDoc AuthFormEntryStore.selectedIdp} */
    selectedIdp: IdentityProvider;
    /** {@inheritDoc AuthFormEntryStore.ssoToggled} */
    ssoToggled: boolean;
    /** {@inheritDoc AuthFormEntryStore.termsAgreed} */
    termsAgreed: boolean;
    /** {@inheritDoc AuthFormEntryStore.autofilling} */
    autofilling: boolean;
    /** {@inheritDoc AuthFormEntryStore.orgUsername} */
    get orgUsername(): string;
    constructor();
    /**
     * @internal
     */
    protected resetIDPState(): void;
    /**
     * @internal
     */
    protected autofill(): Promise<boolean>;
    /** {@inheritDoc AuthFormEntryStore.onAutofillForm} */
    onAutofillForm: EventListener;
    /** {@inheritDoc AuthFormEntryStore.onOrganisationChanged} */
    onOrganisationChanged: EventListener;
    /** {@inheritDoc AuthFormEntryStore.onUsernameChanged} */
    onUsernameChanged: EventListener;
    /** {@inheritDoc AuthFormEntryStore.onEmailChanged} */
    onEmailChanged: EventListener;
    /** {@inheritDoc AuthFormEntryStore.onPasswordChanged} */
    onPasswordChanged: EventListener;
    /** {@inheritDoc AuthFormEntryStore.onPassword2Changed} */
    onPassword2Changed: EventListener;
    /** {@inheritDoc AuthFormEntryStore.onShowPasswordChanged} */
    onShowPasswordChanged: EventListener;
    /** {@inheritDoc AuthFormEntryStore.onSelectedIdpChanged} */
    onSelectedIdpChanged: EventListener;
    /** {@inheritDoc AuthFormEntryStore.onSSOToggleChanged} */
    onSSOToggleChanged: EventListener;
    /**
     * @privateRemarks
     * Internally observed given constructor assignment.
     * @internal
     */
    protected ssoToggledChanged: (prev: boolean, next: boolean) => Promise<void>;
    /** {@inheritDoc AuthFormEntryStore.ssoLoginUrl} */
    get ssoLoginUrl(): string;
}
/**
 * AuthFormEntryStore DI key.
 * @internal
 */
export declare const AuthFormEntryStore: import("@microsoft/fast-foundation").InterfaceSymbol<AuthFormEntryStore>;
export {};
//# sourceMappingURL=authFormEntry.d.ts.map