import { getUser } from '@genesislcap/foundation-user';
import { css } from '@microsoft/fast-element';
import { DI } from '@microsoft/fast-foundation';
import { Route } from '@microsoft/fast-router';
import defaultBackgroundSrc from '../assets/bg.jpg';
import defaultLogoSrc from '../assets/genesis-logo-light.svg';
import { navigateTo } from '../routes/utils';
import localizationResources from '../translation.json';
import { defaultTemplateOptions } from './templates';
/**
 * Default AuthConfig DI implementation.
 * @public
 */
export const defaultAuthConfig = {
    name: 'foundation-auth',
    templateOptions: defaultTemplateOptions,
    logo: css `
    content: url(${defaultLogoSrc});
  `,
    background: css `
    :host {
      background-image: url(${defaultBackgroundSrc});
    }
  `,
    backgroundVideo: null,
    omitRoutes: [],
    fields: {
        organisation: null,
        username: {
            label: 'Username',
            pattern: '^[a-zA-Z0-9.@_\\-]*$',
            title: 'Letters, numbers, and limited special characters @ _ - .',
        },
        email: {
            label: 'Email Address',
        },
        password: {
            label: 'Password',
        },
    },
    hostPath: '',
    omitRedirectUrls: ['/not-found', '/not-permitted'],
    postLoginRedirect: () => { var _a; return navigateTo((_a = getUser().lastPath()) !== null && _a !== void 0 ? _a : 'protected'); },
    postLogoutRedirect: () => {
        const currentRoute = Route.path.current;
        if (currentRoute && currentRoute.includes('logout')) {
            navigateTo('/');
        }
    },
    sso: {
        toggled: false,
    },
    feedbackDelay: 3000,
    localizationResources,
};
/**
 * AuthConfig DI key.
 *
 * @internal
 * @privateRemarks
 * Marked as internal to stop api-extractor becoming confused cross-linking tokens with the same name.
 */
export const AuthConfig = DI.createInterface((x) => x.instance(defaultAuthConfig));
