import { __awaiter, __decorate } from "tslib";
import { assert, createComponentSuite } from '@genesislcap/foundation-testing';
import { customElement, FASTElement, html } from '@microsoft/fast-element';
import { CredentialManager } from './credentialManager';
/**
 * Container PasswordCredentials
 */
const validCredential = {
    id: 'support@genesis.global',
    name: 'support@genesis.global',
    password: 'supportPassword',
};
const validCredentialWithCompId = Object.assign(Object.assign({}, validCredential), { id: 'support@genesis.global:GENESIS' });
/**
 * Malformed container PasswordCredentials
 */
const malformedCredential1 = {
    id: 'support@genesis.global',
    name: '',
    password: 'supportPassword',
};
const malformedCredential2 = {
    id: '',
    name: 'support@genesis.global',
    password: 'supportPassword',
};
const malformedCredential3 = {
    id: 'support@genesis.global:GENESIS',
    name: '',
    password: 'supportPassword',
};
const malformedCredential4 = {
    id: '',
    name: 'support@genesis.global:GENESIS',
    password: 'supportPassword',
};
const malformedCredential5 = {
    name: 'JaneDoe',
};
const malformedCredential6 = {
    id: 'Joe:GENESIS:Joe',
    name: 'Joe',
    password: 'supportPassword',
};
const malformedCredential7 = {
    id: 'Joe',
    name: 'Joe:GENESIS:Joe',
    password: 'supportPassword',
};
const malformedCredential8 = {
    id: 's Joe',
    name: '   Joe:GENESIS:Joe   ',
    password: 'supportPassword',
};
const malformedCredential9 = {
    id: '                Joe:GENESIS:Jo   ',
    name: '  Joe:GENESIS:Joe   ',
    password: 'supportPassword',
};
const validCookie = {
    id: 'support@genesis.global',
    name: 'support@genesis.global',
};
const validCookieWithCompId = {
    id: 'support@genesis.global:GENESIS',
    name: 'support@genesis.global',
};
/**
 * Cookies in a previously KNOWN FORMAT
 */
const validPreviousCookie = {
    organisation: '',
    username: 'support@genesis.global',
    password: 'supportPassword',
};
const validPreviousCookieWithCompId = {
    organisation: 'GENESIS',
    username: 'support@genesis.global',
    password: 'supportPassword',
};
/**
 * Malformed cookies
 */
const malformedCookie1 = {
    organisation: '',
    username: 'support@genesis.global:GENESIS',
    password: 'supportPassword',
};
const malformedCookie2 = {
    organisation: 'support@genesis.global:GENESIS',
    username: '',
    password: 'supportPassword',
};
const malformedCookie3 = {
    organisation: '',
    username: 'support@genesis.global',
    password: 'supportPassword',
};
const malformedCookie4 = {
    organisation: 'support@genesis.global',
    username: '',
    password: 'supportPassword',
};
const malformedCookie5 = {
    organisation: 'GENESIS',
    username: 'support@genesis.global:GENESIS',
    password: 'supportPassword',
};
const malformedCookie6 = {
    organisation: 'support@genesis.global:GENESIS',
    username: 'support@genesis.global:GENESIS',
    password: 'supportPassword',
};
const malformedCookie7 = {
    name: 'support@genesis.global', // < name instead of username
};
const malformedCookie8 = {
    username: 'JohnDoe:GENESIS',
    password: 'supportPassword',
};
const malformedCookie9 = {
    username: 'Joe:GENESIS:Joe',
    password: 'supportPassword',
};
const malformedCookie10 = {
    name: 'Joe:GENESIS:Joe',
};
const malformedCookie11 = {
    organisation: '  ',
    username: '   support@genesis.global   ',
    password: 'supportPassword',
};
let TestElement = class TestElement extends FASTElement {
};
__decorate([
    CredentialManager
], TestElement.prototype, "credentialManager", void 0);
TestElement = __decorate([
    customElement({
        name: 'credential-manager-test-element',
        template: html `
    <slot></slot>
  `,
    })
], TestElement);
const Suite = createComponentSuite('CredentialManager', 'credential-manager-test-element');
Suite('Can be created in the DOM', ({ element }) => __awaiter(void 0, void 0, void 0, function* () {
    assert.ok(element);
}));
Suite('Element has credentialManager injected', ({ element }) => __awaiter(void 0, void 0, void 0, function* () {
    assert.ok(element.credentialManager);
}));
Suite('validateUserCredentialData should provide expected results for PasswordCredentials', ({ element, runCases }) => __awaiter(void 0, void 0, void 0, function* () {
    runCases(element.credentialManager.validateUserCredentialData, [
        [[validCredential, true], true],
        [[validCredentialWithCompId, true], true],
        [[malformedCredential1, true], false],
        [[malformedCredential2, true], false],
        [[malformedCredential3, true], false],
        [[malformedCredential4, true], false],
        [[malformedCredential5, true], false],
        [[malformedCredential6, true], false],
        [[malformedCredential7, true], false],
        [[malformedCredential8, true], false],
        [[malformedCredential9, true], false],
    ]);
}));
Suite('validateUserCredentialData should provide expected results for cookies', ({ element, runCases }) => __awaiter(void 0, void 0, void 0, function* () {
    runCases(element.credentialManager.validateUserCredentialData, [
        [[validCookie], true],
        [[validCookieWithCompId], true],
        [[validPreviousCookie], false],
        [[validPreviousCookieWithCompId], false],
        [[malformedCookie1], false],
        [[malformedCookie2], false],
        [[malformedCookie3], false],
        [[malformedCookie4], false],
        [[malformedCookie5], false],
        [[malformedCookie6], false],
        [[malformedCookie7], false],
        [[malformedCookie8], false],
        [[malformedCookie9], false],
        [[malformedCookie10], false],
        [[malformedCookie11], false],
    ]);
}));
Suite('normaliseLegacyCredentialData should provide expected base case results', ({ element, runCases }) => __awaiter(void 0, void 0, void 0, function* () {
    const cm = element.credentialManager;
    runCases(cm.normaliseLegacyCredentialData.bind(cm), [
        [
            [validCredential, validCookie],
            [validCredential, true],
        ],
        [
            [validCredential, malformedCookie1],
            [validCredential, true],
        ],
        [
            [validCredential, undefined],
            [validCredential, true],
        ],
        [
            [validCredentialWithCompId, validCookie],
            [validCredentialWithCompId, true],
        ],
        [
            [validCredentialWithCompId, malformedCookie2],
            [validCredentialWithCompId, true],
        ],
        [
            [validCredentialWithCompId, undefined],
            [validCredentialWithCompId, true],
        ],
        [
            [malformedCredential1, validCookie],
            [validCookie, false],
        ],
        [
            [undefined, validCookie],
            [validCookie, false],
        ],
        [
            [undefined, undefined],
            [undefined, false],
        ],
        [
            [null, null],
            [undefined, false],
        ],
        [
            [null, undefined],
            [undefined, false],
        ],
        [
            [undefined, null],
            [undefined, false],
        ],
    ]);
}));
Suite('normaliseLegacyCredentialData should provide expected legacy cookie migration results', ({ element, runCases }) => __awaiter(void 0, void 0, void 0, function* () {
    const cm = element.credentialManager;
    runCases(cm.normaliseLegacyCredentialData.bind(cm), [
        [
            [malformedCredential1],
            [
                {
                    id: 'support@genesis.global',
                    name: 'support@genesis.global',
                    password: 'supportPassword',
                },
                true,
            ],
        ],
        [
            [malformedCredential2],
            [
                {
                    id: 'support@genesis.global',
                    name: 'support@genesis.global',
                    password: 'supportPassword',
                },
                true,
            ],
        ],
        [
            [malformedCredential3],
            [
                {
                    id: 'support@genesis.global:GENESIS',
                    name: 'support@genesis.global',
                    password: 'supportPassword',
                },
                true,
            ],
        ],
        [
            [malformedCredential4],
            [
                {
                    id: 'support@genesis.global:GENESIS',
                    name: 'support@genesis.global',
                    password: 'supportPassword',
                },
                true,
            ],
        ],
        [
            [malformedCredential5],
            [
                {
                    id: 'JaneDoe',
                    name: 'JaneDoe',
                    password: '',
                },
                true,
            ],
        ],
        [
            [malformedCredential6],
            [
                {
                    id: 'Joe:GENESIS',
                    name: 'Joe',
                    password: 'supportPassword',
                },
                true,
            ],
        ],
        [
            [malformedCredential7],
            [
                {
                    id: 'Joe:GENESIS',
                    name: 'Joe',
                    password: 'supportPassword',
                },
                true,
            ],
        ],
        [
            [malformedCredential8],
            [
                {
                    id: 'Joe:GENESIS',
                    name: 'Joe',
                    password: 'supportPassword',
                },
                true,
            ],
        ],
        [
            [malformedCredential9],
            [
                {
                    id: 'Joe:GENESIS',
                    name: 'Joe',
                    password: 'supportPassword',
                },
                true,
            ],
        ],
    ]);
}));
Suite('normaliseLegacyCredentialData should provide expected legacy cookie migration results', ({ element, runCases }) => __awaiter(void 0, void 0, void 0, function* () {
    const cm = element.credentialManager;
    runCases(cm.normaliseLegacyCredentialData.bind(cm), [
        [
            [undefined, malformedCookie1],
            [
                {
                    id: 'support@genesis.global:GENESIS',
                    name: 'support@genesis.global',
                    password: 'supportPassword',
                },
                false,
            ],
        ],
        [
            [undefined, malformedCookie2],
            [
                {
                    id: 'support@genesis.global:GENESIS',
                    name: 'support@genesis.global',
                    password: 'supportPassword',
                },
                false,
            ],
        ],
        [
            [undefined, malformedCookie3],
            [
                {
                    id: 'support@genesis.global',
                    name: 'support@genesis.global',
                    password: 'supportPassword',
                },
                false,
            ],
        ],
        [
            [undefined, malformedCookie4],
            [
                {
                    id: 'support@genesis.global',
                    name: 'support@genesis.global',
                    password: 'supportPassword',
                },
                false,
            ],
        ],
        [
            [undefined, malformedCookie5],
            [
                {
                    id: 'support@genesis.global:GENESIS',
                    name: 'support@genesis.global',
                    password: 'supportPassword',
                },
                false,
            ],
        ],
        [
            [undefined, malformedCookie6],
            [
                {
                    id: 'support@genesis.global:GENESIS',
                    name: 'support@genesis.global',
                    password: 'supportPassword',
                },
                false,
            ],
        ],
        [
            [undefined, malformedCookie7],
            [
                {
                    id: 'support@genesis.global',
                    name: 'support@genesis.global',
                    password: '',
                },
                false,
            ],
        ],
        [
            [undefined, malformedCookie8],
            [
                {
                    id: 'JohnDoe:GENESIS',
                    name: 'JohnDoe',
                    password: 'supportPassword',
                },
                false,
            ],
        ],
        [
            [undefined, malformedCookie9],
            [
                {
                    id: 'Joe:GENESIS',
                    name: 'Joe',
                    password: 'supportPassword',
                },
                false,
            ],
        ],
        [
            [undefined, malformedCookie10],
            [
                {
                    id: 'Joe:GENESIS',
                    name: 'Joe',
                    password: '',
                },
                false,
            ],
        ],
        [
            [undefined, malformedCookie11],
            [
                {
                    id: 'support@genesis.global',
                    name: 'support@genesis.global',
                    password: 'supportPassword',
                },
                false,
            ],
        ],
    ]);
}));
Suite.run();
