import { isErrorEvent } from '@genesislcap/foundation-state-machine';
import { assign } from 'xstate';
import { logger } from '../utils';
import { NackError } from './errors';
import { is200Nack } from './guards';
/**
 * Set error action.
 * @remarks
 * Used to set a top level error on the machine. This may equal to {@link @genesislcap/foundation-utils#ErrorMap} `lastError` in the `errors` property.
 * @public
 */
export const setError = assign(({ event }) => {
    if (isErrorEvent(event)) {
        return {
            error: event.data,
        };
    }
    if (is200Nack(event)) {
        logger.debug(`setError action called with non error event type.`, event);
        return {
            error: NackError.fromEntity(event.output),
        };
    }
});
