import { APIError } from '@genesislcap/foundation-state-machine';
/**
 * NackError.
 *
 * @privateRemarks
 * Is required until http status codes are aligned on backend.
 *
 * @example
 * ```ts
 * NackError.fromEntity(event.output);
 * ```
 *
 * @public
 */
export class NackError extends APIError {
    constructor(status, data, message = 'API Error Occurred') {
        super(status, data, message);
        this.status = status;
        this.data = data;
    }
    /**
     * Construct a {@link NackError} from a {@link Nack}
     * @param entity - The Nack.
     */
    static fromEntity(entity) {
        if (!entity) {
            return null;
        }
        /**
         * Prioritize errors
         */
        if (entity.normalisedErrorStatusCode > 0) {
            return new NackError(entity.normalisedErrorStatusCode, entity, entity.normalisedErrorText);
        }
        if (entity.normalisedWarningStatusCode > 0) {
            return new NackError(entity.normalisedWarningStatusCode, entity, entity.normalisedWarningText);
        }
        return null;
    }
}
