import { CredentialType } from '../credential';
/**
 * Default AuthMachineContext.
 * @public
 */
export const defaultAuthMachineContext = {
    params: undefined,
    dto: undefined,
    entity: undefined,
    user: undefined,
};
/**
 * isLoginParams.
 * @param params - Potential LoginParams.
 * @public
 */
export function isLoginParams(params) {
    const loginParams = params;
    return (loginParams === null || loginParams === void 0 ? void 0 : loginParams.type) && Object.keys(CredentialType).includes(loginParams.type);
}
/**
 * isForgotPasswordParams.
 * @remarks
 * ForgotPasswordParams.requester is optional, so it is not part of the evaluation.
 * @param params - Potential ForgotPasswordParams.
 * @public
 */
export function isForgotPasswordParams(params) {
    const p = params;
    return p && !!p.username && !!p.returnUrl;
}
/**
 * isChangePasswordParams.
 * @remarks
 * ChangePasswordParams.requester is optional, so it is not part of the evaluation.
 * @param params - Potential ChangePasswordParams.
 * @public
 */
export function isChangePasswordParams(params) {
    const p = params;
    return p && !!p.username && !!p.oldPassword && !!p.newPassword;
}
/**
 * isResetPasswordParams.
 * @remarks
 * ResetPasswordParams.requester is optional, so it is not part of the evaluation.
 * @param params - Potential ResetPasswordParams.
 * @public
 */
export function isResetPasswordParams(params) {
    const p = params;
    return p && !!p.username && !!p.resetToken && !!p.newPassword;
}
/**
 * isQueryParams.
 * @param params - Potential QueryParams.
 * @public
 */
export function isQueryParams(params) {
    const queryParams = params;
    return queryParams && (queryParams.SSO_TOKEN !== undefined || queryParams.MFA_CODE !== undefined);
}
