import { __decorate } from "tslib";
import { UUID } from '@genesislcap/foundation-utils';
import { DI } from '@microsoft/fast-foundation';
import { MESSAGE_TYPE } from '../dto';
import { isChangePasswordParams, isForgotPasswordParams, isResetPasswordParams, } from '../machine/types';
import { logger } from '../utils';
import { MappingError } from './error';
/**
 * Default PasswordManagementMapper.
 * @public
 */
export class DefaultPasswordManagementMapper {
    constructor() {
        /**
         * {@inheritDoc Mapper.toDTO}
         */
        this.toDTO = (entity) => {
            var _a, _b;
            try {
                const params = entity;
                if (isForgotPasswordParams(params)) {
                    const dto = {
                        USER_NAME: (_a = params.requester) !== null && _a !== void 0 ? _a : params.username,
                        SOURCE_REF: this.uuid.createId(),
                        MESSAGE_TYPE: MESSAGE_TYPE.FORGOT_PASSWORD,
                        DETAILS: {
                            USER_NAME: params.username,
                            RETURN_URL: params.returnUrl,
                        },
                    };
                    return dto;
                }
                if (isChangePasswordParams(params)) {
                    const dto = {
                        USER_NAME: params.username,
                        SOURCE_REF: this.uuid.createId(),
                        MESSAGE_TYPE: MESSAGE_TYPE.CHANGE_PASSWORD,
                        DETAILS: {
                            OLD_PASSWORD: params.oldPassword,
                            NEW_PASSWORD: params.newPassword,
                        },
                    };
                    return dto;
                }
                if (isResetPasswordParams(params)) {
                    const dto = {
                        USER_NAME: (_b = params.requester) !== null && _b !== void 0 ? _b : params.username,
                        SOURCE_REF: this.uuid.createId(),
                        MESSAGE_TYPE: MESSAGE_TYPE.RESET_PASSWORD,
                        DETAILS: {
                            USER_NAME: params.username,
                            RESET_TOKEN: params.resetToken,
                            NEW_PASSWORD: params.newPassword,
                        },
                    };
                    return dto;
                }
                throw new Error('No DTO mapping implementation for provided entity');
            }
            catch (e) {
                logger.error(e);
                throw new MappingError(entity);
            }
        };
    }
}
__decorate([
    UUID
], DefaultPasswordManagementMapper.prototype, "uuid", void 0);
/**
 * PasswordManagementMapper DI key.
 *
 * @privateRemarks
 * Marked as internal to stop api-extractor becoming confused cross-linking tokens with the same name.
 *
 * @internal
 */
export const PasswordManagementMapper = DI.createInterface((x) => x.singleton(DefaultPasswordManagementMapper));
