import { __awaiter, __decorate } from "tslib";
import { customElement } from '@microsoft/fast-element';
import { commonStyles } from '../../styles';
import { logger } from '../../utils';
import { BaseRoute } from '../base';
import { ForgotPasswordTemplate as template } from './forgot-password.template';
/**
 * ForgotPassword
 *
 * @fires auth-forgot-password - Fires a custom 'auth-forgot-password' event.
 * @fires auth-organisation-changed - Fires a custom 'auth-organisation-changed' event.
 * @fires auth-username-changed - Fires a custom 'auth-username-changed' event.
 *
 * @public
 */
let ForgotPassword = class ForgotPassword extends BaseRoute {
    onSubmit() {
        return __awaiter(this, void 0, void 0, function* () {
            logger.debug('forgot password submission');
            /**
             * Example url from email: https://public-foundation.genesislab.global/reset-password?password=nc_cbGrlgCkZeJHAF043oqEidnk
             */
            this.$emit('auth-forgot-password', {
                username: this.store.formEntry.orgUsername,
                returnUrl: this.routing.getForgotPasswordReturnUrl(),
            });
        });
    }
};
ForgotPassword = __decorate([
    customElement({
        name: 'foundation-auth-forgot-password',
        template,
        styles: commonStyles,
    })
], ForgotPassword);
export { ForgotPassword };
