import { targetChecked } from '@genesislcap/foundation-events';
import { html, repeat, when } from '@microsoft/fast-element';
import { anchorTag, buttonTag, cardTag, checkboxTag, listboxOptionTag, selectTag, } from '../../tags';
import { organisationField, passwordField, showPasswordCheckbox, usernameField, submitButton, selectEmit, } from '../base';
const regularLogin = html `
  ${when((login) => !login.store.formEntry.ssoToggled, html `
      ${organisationField()} ${usernameField()} ${passwordField()}
      <span class="case-warning">${(x) => x.toLocalisedText('LOGIN_CASE_WARNING')}</span>
      ${showPasswordCheckbox()}
      <div class="form-buttons">
        ${(x) => submitButton(x.toLocalisedText('LOGIN_SUBMIT_BUTTON'), 'submit', x.submitDisabled)}
        <div class="links">
          <div class="password-links">
            ${when((x) => !x.config.omitRoutes.includes('forgot-password'), html `
                <${anchorTag}
                  class="link-url"
                  appearance="lightweight"
                  @click=${(x) => x.routing.navigateTo(`forgot-password`)}
                  data-test-id="forgot-password"
                >
                  ${(x) => x.toLocalisedText('LOGIN_FORGOT_PASSWORD_LINK')}
                </${anchorTag}>
              `)}
            ${when((x) => !x.config.omitRoutes.includes('reset-password'), html `
                <${anchorTag}
                  class="link-url"
                  appearance="lightweight"
                  @click=${(x) => x.routing.navigateTo(`reset-password`)}
                  data-test-id="reset-password"
                >
                  ${(x) => x.toLocalisedText('LOGIN_CHANGE_PASSWORD_LINK')}
                </${anchorTag}>
              `)}
          </div>
          <div class="account-links">
            ${when((x) => !x.config.omitRoutes.includes('request-account'), html `
                <${anchorTag}
                  class="link-url"
                  appearance="lightweight"
                  @click=${(x) => x.routing.navigateTo(`request-account`)}
                  data-test-id="request-account"
                >
                  ${(x) => x.toLocalisedText('LOGIN_REQUEST_ACCOUNT_LINK')}
                </${anchorTag}>
              `)}
          </div>
        </div>
      </div>
      ${when((x) => x.config.versionInformation, html `
          <div>
            <span class="version" data-test-id="version">
              ${(x) => x.config.versionInformation}
            </span>
          </div>
        `)}
    `)}
`;
const ssoLogin = html `
  ${when((login) => login.store.formEntry.ssoToggled, html `
      <div class="sso">
        <span class="form-title">Providers</span>
        <${selectTag}
          name="sso"
          data-test-id="sso"
          @change="${selectEmit('auth-selectedIdp-changed')}"
          ?disabled=${(x) => !x.store.formEntry.idps.length}
        >
          ${repeat((x) => x.store.formEntry.idps, html `
              <${listboxOptionTag}
                value=${({ id }) => id}
                ?selected=${(x, c) => c.parent.store.formEntry.selectedIdp === x}
              >
                ${({ id }) => id}
              </${listboxOptionTag}>
            `)}
        </${selectTag}>
        <${buttonTag}
          type="button"
          class="action-btn"
          appearance="primary-gradient"
          @click="${(x) => x.onSSOLogin()}"
          data-test-id="submit"
          ?disabled=${(x) => !x.store.formEntry.selectedIdp}
        >
          ${(x) => x.toLocalisedText('LOGIN_SSO_BUTTON')}
        </${buttonTag}>
      </div>
    `)}
`;
/**
 * LoginTemplate
 * @public
 */
export const LoginTemplate = html `
  <auth-background>
    <div class="container">
      <${cardTag} class="card-pd">
        <div class="column-content">
          <auth-logo></auth-logo>
          <div class="heading2" data-test-id="heading">${(x) => x.toLocalisedText('LOGIN_TITLE')}</div>
        </div>
        <form
          id="auth-login"
          method="post"
          autocomplete="on"
          @submit=${(x) => x.onLoginSubmit()}
          ?disabled=${(x) => x.submitDisabled}
          data-test-id="form"
        >
          ${regularLogin} ${ssoLogin}
          ${when((x) => x.config.sso, html `
              <${checkboxTag}
                ?checked="${(x) => x.store.formEntry.ssoToggled}"
                @change="${(x, c) => x.$emit('auth-ssoToggled-changed', targetChecked(c))}"
                name="sso-toggle"
                data-test-id="sso-toggle"
              >
                ${(x) => x.ssoToggleLabel}
              </${checkboxTag}>
            `)}
          <submitting-indicator is-submitting="${(x) => x.store.isPending}"></submitting-indicator>
          <auth-message></auth-message>
        </form>
      </${cardTag}>
    </div>
  </auth-background>
`;
