import { Route } from '@microsoft/fast-router';
import { AuthRoutes } from './types';
/**
 * A utility to check if a pathname is a route of this micro frontend.
 *
 * @param pathname - A pathname string to check, typically location.pathname, which is used when a value is omitted.
 *
 * @public
 * @privateRemarks
 * I've just put this util in for now given there's some app level direction code in place which needs review.
 */
export function isMFRoute(pathname = location.pathname) {
    const valueParts = pathname.split('/');
    const routeIdx = pathname.charAt(0) === '/' ? 1 : 0;
    const route = valueParts[routeIdx];
    return !!AuthRoutes[route];
}
/**
 * @remarks
 * Uses the `FASTRouter`.
 *
 * @param route - An auth route including query params if required, ie. `reset-password?expired`.
 *
 * @internal
 */
export function navigateTo(route) {
    Route.path.push(route);
}
/**
 * A utility to get a sub route path taking the host path into account.
 *
 * @param route - An auth route.
 * @param hostPath - The host path.
 *
 * @public
 */
export function getRoutePath(route, hostPath = '') {
    if (route === '/') {
        return route;
    }
    if (route === '') {
        return hostPath ? hostPath : route;
    }
    return hostPath ? `${hostPath}/${route}` : route;
}
